@@ -10,18 +10,18 @@ AccountType = Dict[str, Any]
 class IdentityAccessManager(AccountManagerMixin, DiscoveryMixin, GoogleCloudPilotAPI):
     def __init__(self, **kwargs):
         super().__init__(
-            serviceName='iam',
-            version='v1',
+            serviceName="iam",
+            version="v1",
             cache_discovery=False,
             **kwargs,
         )
 
     def _service_account_path(self, email: str, project_id: str = None) -> str:
         parent_path = self._project_path(project_id=project_id)
-        return f'{parent_path}/serviceAccounts/{email}'
+        return f"{parent_path}/serviceAccounts/{email}"
 
     def _build_service_account_email(self, name: str, project_id: str = None) -> str:
-        return f'{name}@{project_id or self.project_id}.iam.gserviceaccount.com'
+        return f"{name}@{project_id or self.project_id}.iam.gserviceaccount.com"
 
     async def get_service_account(self, name: str, project_id: str = None) -> AccountType:
         account_path = self._service_account_path(
@@ -35,19 +35,14 @@ class IdentityAccessManager(AccountManagerMixin, DiscoveryMixin, GoogleCloudPilo
         )
 
     async def create_service_account(
-            self,
-            name: str,
-            display_name: str,
-            project_id: str = None,
-            exists_ok: bool = True,
+        self,
+        name: str,
+        display_name: str,
+        project_id: str = None,
+        exists_ok: bool = True,
     ) -> AccountType:
         try:
-            body = {
-                'accountId': name,
-                'serviceAccount': {
-                    'displayName': display_name
-                }
-            }
+            body = {"accountId": name, "serviceAccount": {"displayName": display_name}}
             service_account = self._execute(
                 method=self.client.projects().serviceAccounts().create,
                 name=self._project_path(project_id=project_id),
@@ -65,7 +60,7 @@ class IdentityAccessManager(AccountManagerMixin, DiscoveryMixin, GoogleCloudPilo
         )
         pagination = self._paginate(
             method=self.client.projects().serviceAccounts().list,
-            result_key='accounts',
+            result_key="accounts",
             params=params,
         )
         for item in pagination:
@@ -79,9 +74,9 @@ class IdentityAccessManager(AccountManagerMixin, DiscoveryMixin, GoogleCloudPilo
         )
 
     def _as_member(self, email: str) -> str:
-        is_service_account = email.endswith('.gserviceaccount.com')
-        prefix = 'serviceAccount' if is_service_account else 'member'
-        return f'{prefix}:{email}'
+        is_service_account = email.endswith(".gserviceaccount.com")
+        prefix = "serviceAccount" if is_service_account else "member"
+        return f"{prefix}:{email}"
 
     async def bind_member(self, target_email: str, member_email: str, role: str, project_id=None) -> PolicyType:
         policy = self.get_policy(email=target_email, project_id=project_id)
@@ -89,11 +84,11 @@ class IdentityAccessManager(AccountManagerMixin, DiscoveryMixin, GoogleCloudPilo
         return self.set_policy(email=target_email, policy=changed_policy, project_id=project_id)
 
     async def remove_member(
-            self,
-            target_email: str,
-            member_email: str,
-            role: str,
-            project_id: str = None,
+        self,
+        target_email: str,
+        member_email: str,
+        role: str,
+        project_id: str = None,
     ) -> PolicyType:
         policy = self.get_policy(email=target_email, project_id=project_id)
         changed_policy = self._unbind_email_from_policy(email=member_email, role=role, policy=policy)
@@ -104,10 +99,8 @@ class IdentityAccessManager(AccountManagerMixin, DiscoveryMixin, GoogleCloudPilo
         return self._execute(
             method=self.client.projects().serviceAccounts().setIamPolicy,
             resource=resource,
-            body={'policy': policy, 'updateMask': 'bindings'},
+            body={"policy": policy, "updateMask": "bindings"},
         )
 
 
-__all__ = (
-    'IdentityAccessManager',
-)
+__all__ = ("IdentityAccessManager",)
